==> react-use-visibility-0.1.0.tgz: package/lib/checkVisibility.test.js <==
"use strict";

var _checkVisibility = _interopRequireDefault(require("./checkVisibility"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('checkVisibility', function () {
  var el;
  beforeEach(function () {
    window.innerWidth = 1024;
    window.innerHeight = 768;
  });
  afterEach(function () {
    window.innerWidth = null;
    window.innerHeight = null;
  });
  describe('with no element', function () {
    beforeEach(function () {
      el = null;
    });
    test('is not visible', function () {
      expect((0, _checkVisibility.default)(el, false)).toBe(false);
    });
    test('is not partially visible', function () {
      expect((0, _checkVisibility.default)(el, true)).toBe(false);
    });
  });
  describe('when element has no size', function () {
    beforeEach(function () {
      el = {
        getBoundingClientRect: function getBoundingClientRect() {
          return {
            top: 0,
            right: 0,
            bottom: 0,
            left: 0,
            width: 0,
            height: 0
          };
        }
      };
    });
    test('is not visible', function () {
      expect((0, _checkVisibility.default)(el, false)).toBe(false);
    });
    test('is not partially visible', function () {
      expect((0, _checkVisibility.default)(el, true)).toBe(false);
    });
  });
  describe('when element is on the screen', function () {
    beforeEach(function () {
      el = {
        getBoundingClientRect: function getBoundingClientRect() {
          return {
            top: 0,
            right: 100,
            bottom: 100,
            left: 0,
            width: 100,
            height: 100
          };
        }
      };
    });
    test('is visible', function () {
      expect((0, _checkVisibility.default)(el, false)).toBe(true);
    });
    test('is partially visible', function () {
      expect((0, _checkVisibility.default)(el, true)).toBe(true);
    });
  });
  describe('when element is not fully on the screen', function () {
    describe('appearing from the top', function () {
      beforeEach(function () {
        el = {
          getBoundingClientRect: function getBoundingClientRect() {
            return {
              top: -50,
              right: 100,
              bottom: 50,
              left: 0,
              width: 100,
              height: 100
            };
          }
        };
      });
      test('is not visible', function () {
        expect((0, _checkVisibility.default)(el, false)).toBe(false);
      });
      test('is partially visible', function () {
        expect((0, _checkVisibility.default)(el, true)).toBe(true);
      });
    });
    describe('appearing from the right', function () {
      beforeEach(function () {
        el = {
          getBoundingClientRect: function getBoundingClientRect() {
            return {
              top: 0,
              right: 1074,
              bottom: 100,
              left: 974,
              width: 100,
              height: 100
            };
          }
        };
      });
      test('is not visible', function () {
        expect((0, _checkVisibility.default)(el, false)).toBe(false);
      });
      test('is partially visible', function () {
        expect((0, _checkVisibility.default)(el, true)).toBe(true);
      });
    });
    describe('appearing from the bottom', function () {
      beforeEach(function () {
        el = {
          getBoundingClientRect: function getBoundingClientRect() {
            return {
              top: 758,
              right: 100,
              bottom: 858,
              left: 0,
              width: 100,
              height: 100
            };
          }
        };
      });
      test('is not visible', function () {
        expect((0, _checkVisibility.default)(el, false)).toBe(false);
      });
      test('is partially visible', function () {
        expect((0, _checkVisibility.default)(el, true)).toBe(true);
      });
    });
    describe('appearing from the left', function () {
      beforeEach(function () {
        el = {
          getBoundingClientRect: function getBoundingClientRect() {
            return {
              top: 0,
              right: 50,
              bottom: 100,
              left: -50,
              width: 100,
              height: 100
            };
          }
        };
      });
      test('is not visible', function () {
        expect((0, _checkVisibility.default)(el, false)).toBe(false);
      });
      test('is partially visible', function () {
        expect((0, _checkVisibility.default)(el, true)).toBe(true);
      });
    });
  });
});

==> react-use-visibility-0.3.0.tgz: package/lib/checkVisibility.test.js <==
"use strict";

var _checkVisibility = _interopRequireDefault(require("./checkVisibility"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('checkVisibility', function () {
  var el;
  beforeEach(function () {
    window.innerWidth = 1024;
    window.innerHeight = 768;
  });
  afterEach(function () {
    window.innerWidth = null;
    window.innerHeight = null;
  });
  describe('with no element', function () {
    beforeEach(function () {
      el = null;
    });
    test('is not visible', function () {
      expect((0, _checkVisibility["default"])(el, false)).toBe(false);
    });
    test('is not partially visible', function () {
      expect((0, _checkVisibility["default"])(el, true)).toBe(false);
    });
  });
  describe('when element has no size', function () {
    beforeEach(function () {
      el = {
        getBoundingClientRect: function getBoundingClientRect() {
          return {
            top: 0,
            right: 0,
            bottom: 0,
            left: 0,
            width: 0,
            height: 0
          };
        }
      };
    });
    test('is not visible', function () {
      expect((0, _checkVisibility["default"])(el, false)).toBe(false);
    });
    test('is not partially visible', function () {
      expect((0, _checkVisibility["default"])(el, true)).toBe(false);
    });
  });
  describe('when element is on the screen', function () {
    beforeEach(function () {
      el = {
        getBoundingClientRect: function getBoundingClientRect() {
          return {
            top: 0,
            right: 100,
            bottom: 100,
            left: 0,
            width: 100,
            height: 100
          };
        }
      };
    });
    test('is visible', function () {
      expect((0, _checkVisibility["default"])(el, false)).toBe(true);
    });
    test('is partially visible', function () {
      expect((0, _checkVisibility["default"])(el, true)).toBe(true);
    });
  });
  describe('when element is not fully on the screen', function () {
    describe('appearing from the top', function () {
      beforeEach(function () {
        el = {
          getBoundingClientRect: function getBoundingClientRect() {
            return {
              top: -50,
              right: 100,
              bottom: 50,
              left: 0,
              width: 100,
              height: 100
            };
          }
        };
      });
      test('is not visible', function () {
        expect((0, _checkVisibility["default"])(el, false)).toBe(false);
      });
      test('is partially visible', function () {
        expect((0, _checkVisibility["default"])(el, true)).toBe(true);
      });
    });
    describe('appearing from the right', function () {
      beforeEach(function () {
        el = {
          getBoundingClientRect: function getBoundingClientRect() {
            return {
              top: 0,
              right: 1074,
              bottom: 100,
              left: 974,
              width: 100,
              height: 100
            };
          }
        };
      });
      test('is not visible', function () {
        expect((0, _checkVisibility["default"])(el, false)).toBe(false);
      });
      test('is partially visible', function () {
        expect((0, _checkVisibility["default"])(el, true)).toBe(true);
      });
    });
    describe('appearing from the bottom', function () {
      beforeEach(function () {
        el = {
          getBoundingClientRect: function getBoundingClientRect() {
            return {
              top: 758,
              right: 100,
              bottom: 858,
              left: 0,
              width: 100,
              height: 100
            };
          }
        };
      });
      test('is not visible', function () {
        expect((0, _checkVisibility["default"])(el, false)).toBe(false);
      });
      test('is partially visible', function () {
        expect((0, _checkVisibility["default"])(el, true)).toBe(true);
      });
    });
    describe('appearing from the left', function () {
      beforeEach(function () {
        el = {
          getBoundingClientRect: function getBoundingClientRect() {
            return {
              top: 0,
              right: 50,
              bottom: 100,
              left: -50,
              width: 100,
              height: 100
            };
          }
        };
      });
      test('is not visible', function () {
        expect((0, _checkVisibility["default"])(el, false)).toBe(false);
      });
      test('is partially visible', function () {
        expect((0, _checkVisibility["default"])(el, true)).toBe(true);
      });
    });
  });
});
